# dls-icons-vue-3

![](https://img.shields.io/npm/v/dls-icons-vue.svg)

## Installation

```shell
npm i -D dls-icons-vue-3
```

## Usage

### As Vue component

[Demo →](https://stackblitz.com/edit/dls-icons-vue-3-demo?file=src%2FApp.vue)

```vue
<script setup>
import { IconArrowRight } from 'dls-icons-vue-3'
</script>

<template>
<div class="title">
  <h1>
    Hello Icons
    <icon-arrow-right style="{ color: '#999', marginLeft: '5px' }" />
  </h1>
</div>
</template>
```

#### Props

##### `spin: boolean`

Whether the icon is spinning. Default: `false`. You can use `--dls-icon-spin-duration` to customize the time it takes for one turn. The default value is `1s`.

##### `active: boolean`

Whether the icon is active. Default: `undefined`. If `active` is `undefined`, the icon will be in default state. Otherwise it will be in active or inactive state depending on the truthiness of `active`.

> **Note**
> To make `active` prop work properly, you should render a `SharedResources` component in your root component. eg.
>
> ```vue
> <script setup>
> import { SharedResources } from 'dls-icons-vue-3'
> </script>
>
> <template>
>   <SharedResources />
>   <div id="app">...</div>
> </template>
> ```

### As icon data

```js
import { dataArrowRight } from 'dls-icons-vue-3'

/*
{
  {
    name: 'icon-arrow-right',
    content: '<path d="..." ...',
    width: 24,
    height: 24
  }
}
*/
console.log(dataArrowRight)
```

## Available Icons

<!-- icons:start --><table><tbody><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ab-test.svg" height="24"/><br/><sub>IconAbTest</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ab-test-solid.svg" height="24"/><br/><sub>IconAbTestSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/abstract.svg" height="24"/><br/><sub>IconAbstract</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/abstract-solid.svg" height="24"/><br/><sub>IconAbstractSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/academic-cap.svg" height="24"/><br/><sub>IconAcademicCap</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/academic-cap-solid.svg" height="24"/><br/><sub>IconAcademicCapSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ad-delivery-circle-solid.svg" height="24"/><br/><sub>IconAdDeliveryCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ai.svg" height="24"/><br/><sub>IconAi</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/align-bottom.svg" height="24"/><br/><sub>IconAlignBottom</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/align-center.svg" height="24"/><br/><sub>IconAlignCenter</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/align-left.svg" height="24"/><br/><sub>IconAlignLeft</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/align-right.svg" height="24"/><br/><sub>IconAlignRight</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/align-top.svg" height="24"/><br/><sub>IconAlignTop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/android.svg" height="24"/><br/><sub>IconAndroid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/anticlockwise.svg" height="24"/><br/><sub>IconAnticlockwise</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/app-store.svg" height="24"/><br/><sub>IconAppStore</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/apps.svg" height="24"/><br/><sub>IconApps</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/apps-settings.svg" height="24"/><br/><sub>IconAppsSettings</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/apps-settings-solid.svg" height="24"/><br/><sub>IconAppsSettingsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/apps-solid.svg" height="24"/><br/><sub>IconAppsSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-curve-down-right-solid.svg" height="24"/><br/><sub>IconArrowCurveDownRightSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-curve-up-right-solid.svg" height="24"/><br/><sub>IconArrowCurveUpRightSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-down.svg" height="24"/><br/><sub>IconArrowDown</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-down-solid.svg" height="24"/><br/><sub>IconArrowDownSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-left.svg" height="24"/><br/><sub>IconArrowLeft</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-left-solid.svg" height="24"/><br/><sub>IconArrowLeftSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-right.svg" height="24"/><br/><sub>IconArrowRight</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-right-solid.svg" height="24"/><br/><sub>IconArrowRightSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-to-bottom.svg" height="24"/><br/><sub>IconArrowToBottom</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-to-top.svg" height="24"/><br/><sub>IconArrowToTop</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-to-top-soild.svg" height="24"/><br/><sub>IconArrowToTopSoild</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-up.svg" height="24"/><br/><sub>IconArrowUp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/arrow-up-solid.svg" height="24"/><br/><sub>IconArrowUpSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/asterisk.svg" height="24"/><br/><sub>IconAsterisk</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/attribute.svg" height="24"/><br/><sub>IconAttribute</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/attribute-solid.svg" height="24"/><br/><sub>IconAttributeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/audio.svg" height="24"/><br/><sub>IconAudio</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/audio-solid.svg" height="24"/><br/><sub>IconAudioSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/baby-bottle.svg" height="24"/><br/><sub>IconBabyBottle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/baby-bottle-solid.svg" height="24"/><br/><sub>IconBabyBottleSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/background.svg" height="24"/><br/><sub>IconBackground</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/background-solid.svg" height="24"/><br/><sub>IconBackgroundSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bar-chart.svg" height="24"/><br/><sub>IconBarChart</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bar-chart-alt.svg" height="24"/><br/><sub>IconBarChartAlt</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bar-chart-alt-solid.svg" height="24"/><br/><sub>IconBarChartAltSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bar-chart-solid.svg" height="24"/><br/><sub>IconBarChartSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bar-chart-square.svg" height="24"/><br/><sub>IconBarChartSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bar-chart-square-solid.svg" height="24"/><br/><sub>IconBarChartSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bell.svg" height="24"/><br/><sub>IconBell</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bell-solid.svg" height="24"/><br/><sub>IconBellSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bold.svg" height="24"/><br/><sub>IconBold</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/book.svg" height="24"/><br/><sub>IconBook</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/book-bookmark.svg" height="24"/><br/><sub>IconBookBookmark</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/book-bookmark-solid.svg" height="24"/><br/><sub>IconBookBookmarkSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/book-solid.svg" height="24"/><br/><sub>IconBookSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bookmark.svg" height="24"/><br/><sub>IconBookmark</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bookmark-solid.svg" height="24"/><br/><sub>IconBookmarkSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/books-bookmark.svg" height="24"/><br/><sub>IconBooksBookmark</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/books-bookmark-solid.svg" height="24"/><br/><sub>IconBooksBookmarkSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/box.svg" height="24"/><br/><sub>IconBox</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/box-solid.svg" height="24"/><br/><sub>IconBoxSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/building.svg" height="24"/><br/><sub>IconBuilding</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/building-solid.svg" height="24"/><br/><sub>IconBuildingSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bulb.svg" height="24"/><br/><sub>IconBulb</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bulb-dash.svg" height="24"/><br/><sub>IconBulbDash</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bulb-dash-solid.svg" height="24"/><br/><sub>IconBulbDashSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bulb-solid.svg" height="24"/><br/><sub>IconBulbSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bullseye.svg" height="24"/><br/><sub>IconBullseye</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bullseye-hit.svg" height="24"/><br/><sub>IconBullseyeHit</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/bullseye-hit-solid.svg" height="24"/><br/><sub>IconBullseyeHitSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/calendar.svg" height="24"/><br/><sub>IconCalendar</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/calendar-cny.svg" height="24"/><br/><sub>IconCalendarCny</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/calendar-cny-solid.svg" height="24"/><br/><sub>IconCalendarCnySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/calendar-heart.svg" height="24"/><br/><sub>IconCalendarHeart</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/calendar-heart-solid.svg" height="24"/><br/><sub>IconCalendarHeartSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/calendar-solid.svg" height="24"/><br/><sub>IconCalendarSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/camera.svg" height="24"/><br/><sub>IconCamera</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/camera-add.svg" height="24"/><br/><sub>IconCameraAdd</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/camera-add-solid.svg" height="24"/><br/><sub>IconCameraAddSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/camera-solid.svg" height="24"/><br/><sub>IconCameraSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/car.svg" height="24"/><br/><sub>IconCar</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/car-solid.svg" height="24"/><br/><sub>IconCarSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/caret-down.svg" height="24"/><br/><sub>IconCaretDown</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/caret-left.svg" height="24"/><br/><sub>IconCaretLeft</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/caret-right.svg" height="24"/><br/><sub>IconCaretRight</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/caret-up.svg" height="24"/><br/><sub>IconCaretUp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cellphone.svg" height="24"/><br/><sub>IconCellphone</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cellphone-solid.svg" height="24"/><br/><sub>IconCellphoneSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chat.svg" height="24"/><br/><sub>IconChat</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chat-solid.svg" height="24"/><br/><sub>IconChatSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check.svg" height="24"/><br/><sub>IconCheck</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check-circle.svg" height="24"/><br/><sub>IconCheckCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check-circle-solid.svg" height="24"/><br/><sub>IconCheckCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check-desktop.svg" height="24"/><br/><sub>IconCheckDesktop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check-desktop-solid.svg" height="24"/><br/><sub>IconCheckDesktopSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check-square.svg" height="24"/><br/><sub>IconCheckSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/check-square-solid.svg" height="24"/><br/><sub>IconCheckSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-double-down.svg" height="24"/><br/><sub>IconChevronDoubleDown</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-double-left.svg" height="24"/><br/><sub>IconChevronDoubleLeft</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-double-right.svg" height="24"/><br/><sub>IconChevronDoubleRight</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-double-up.svg" height="24"/><br/><sub>IconChevronDoubleUp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-down.svg" height="24"/><br/><sub>IconChevronDown</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-left.svg" height="24"/><br/><sub>IconChevronLeft</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-right.svg" height="24"/><br/><sub>IconChevronRight</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-right-circle.svg" height="24"/><br/><sub>IconChevronRightCircle</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-right-circle-solid.svg" height="24"/><br/><sub>IconChevronRightCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/chevron-up.svg" height="24"/><br/><sub>IconChevronUp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/circle-extend.svg" height="24"/><br/><sub>IconCircleExtend</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/circle-extend-solid.svg" height="24"/><br/><sub>IconCircleExtendSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/circle-rotation.svg" height="24"/><br/><sub>IconCircleRotation</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/circle-rotation-solid.svg" height="24"/><br/><sub>IconCircleRotationSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/clock.svg" height="24"/><br/><sub>IconClock</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/clock-solid.svg" height="24"/><br/><sub>IconClockSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/clockwise.svg" height="24"/><br/><sub>IconClockwise</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cloud-upload-solid.svg" height="24"/><br/><sub>IconCloudUploadSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cny-circle.svg" height="24"/><br/><sub>IconCnyCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cny-circle-solid.svg" height="24"/><br/><sub>IconCnyCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cny-refund.svg" height="24"/><br/><sub>IconCnyRefund</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cny-wallet.svg" height="24"/><br/><sub>IconCnyWallet</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cny-wallet-solid.svg" height="24"/><br/><sub>IconCnyWalletSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/coin.svg" height="24"/><br/><sub>IconCoin</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/coin-solid.svg" height="24"/><br/><sub>IconCoinSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/color-palette.svg" height="24"/><br/><sub>IconColorPalette</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/color-palette-solid.svg" height="24"/><br/><sub>IconColorPaletteSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/compass.svg" height="24"/><br/><sub>IconCompass</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/compass-solid.svg" height="24"/><br/><sub>IconCompassSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/component.svg" height="24"/><br/><sub>IconComponent</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/component-solid.svg" height="24"/><br/><sub>IconComponentSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/copy.svg" height="24"/><br/><sub>IconCopy</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/copy-solid.svg" height="24"/><br/><sub>IconCopySolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/coupon-minus.svg" height="24"/><br/><sub>IconCouponMinus</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/coupon-minus-solid.svg" height="24"/><br/><sub>IconCouponMinusSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/coupon-percent.svg" height="24"/><br/><sub>IconCouponPercent</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/coupon-percent-solid.svg" height="24"/><br/><sub>IconCouponPercentSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/crop.svg" height="24"/><br/><sub>IconCrop</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/crop-solid.svg" height="24"/><br/><sub>IconCropSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/crown.svg" height="24"/><br/><sub>IconCrown</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/crown-solid.svg" height="24"/><br/><sub>IconCrownSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cube.svg" height="24"/><br/><sub>IconCube</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cube-eye.svg" height="24"/><br/><sub>IconCubeEye</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cube-eye-solid.svg" height="24"/><br/><sub>IconCubeEyeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cube-solid.svg" height="24"/><br/><sub>IconCubeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/curve-square.svg" height="24"/><br/><sub>IconCurveSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/curve-square-solid.svg" height="24"/><br/><sub>IconCurveSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/customer.svg" height="24"/><br/><sub>IconCustomer</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/customer-service.svg" height="24"/><br/><sub>IconCustomerService</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/customer-settings.svg" height="24"/><br/><sub>IconCustomerSettings</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/customer-settings-solid.svg" height="24"/><br/><sub>IconCustomerSettingsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/customer-solid.svg" height="24"/><br/><sub>IconCustomerSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cut.svg" height="24"/><br/><sub>IconCut</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/cut-solid.svg" height="24"/><br/><sub>IconCutSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/data.svg" height="24"/><br/><sub>IconData</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/data-market.svg" height="24"/><br/><sub>IconDataMarket</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/data-market-solid.svg" height="24"/><br/><sub>IconDataMarketSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/data-solid.svg" height="24"/><br/><sub>IconDataSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/database.svg" height="24"/><br/><sub>IconDatabase</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/database-solid.svg" height="24"/><br/><sub>IconDatabaseSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/desktop.svg" height="24"/><br/><sub>IconDesktop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/desktop-solid.svg" height="24"/><br/><sub>IconDesktopSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/detail-list.svg" height="24"/><br/><sub>IconDetailList</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/detail-list-solid.svg" height="24"/><br/><sub>IconDetailListSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/diamond.svg" height="24"/><br/><sub>IconDiamond</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/diamond-solid.svg" height="24"/><br/><sub>IconDiamondSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/dollar-circle.svg" height="24"/><br/><sub>IconDollarCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/dollar-circle-solid.svg" height="24"/><br/><sub>IconDollarCircleSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/double-circle.svg" height="24"/><br/><sub>IconDoubleCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/double-circle-solid.svg" height="24"/><br/><sub>IconDoubleCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/download.svg" height="24"/><br/><sub>IconDownload</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/drag-indicator.svg" height="24"/><br/><sub>IconDragIndicator</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/edit.svg" height="24"/><br/><sub>IconEdit</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/edit-solid.svg" height="24"/><br/><sub>IconEditSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/element.svg" height="24"/><br/><sub>IconElement</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/element-solid.svg" height="24"/><br/><sub>IconElementSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ellipsis.svg" height="24"/><br/><sub>IconEllipsis</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ellipsis-circle.svg" height="24"/><br/><sub>IconEllipsisCircle</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ellipsis-circle-solid.svg" height="24"/><br/><sub>IconEllipsisCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/ellipsis-vertical.svg" height="24"/><br/><sub>IconEllipsisVertical</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/english-comment.svg" height="24"/><br/><sub>IconEnglishComment</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/english-comment-solid.svg" height="24"/><br/><sub>IconEnglishCommentSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/envelope.svg" height="24"/><br/><sub>IconEnvelope</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/envelope-open.svg" height="24"/><br/><sub>IconEnvelopeOpen</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/envelope-open-solid.svg" height="24"/><br/><sub>IconEnvelopeOpenSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/envelope-solid.svg" height="24"/><br/><sub>IconEnvelopeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/excellent-bookmark.svg" height="24"/><br/><sub>IconExcellentBookmark</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/excellent-bookmark-solid.svg" height="24"/><br/><sub>IconExcellentBookmarkSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/exclamation-circle.svg" height="24"/><br/><sub>IconExclamationCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/exclamation-circle-solid.svg" height="24"/><br/><sub>IconExclamationCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/exclamation-triangle.svg" height="24"/><br/><sub>IconExclamationTriangle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/exclamation-triangle-solid.svg" height="24"/><br/><sub>IconExclamationTriangleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/expand.svg" height="24"/><br/><sub>IconExpand</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/expand-alt.svg" height="24"/><br/><sub>IconExpandAlt</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/expand-square.svg" height="24"/><br/><sub>IconExpandSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/expand-square-solid.svg" height="24"/><br/><sub>IconExpandSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/external-link.svg" height="24"/><br/><sub>IconExternalLink</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye.svg" height="24"/><br/><sub>IconEye</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye-bright.svg" height="24"/><br/><sub>IconEyeBright</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye-bright-solid.svg" height="24"/><br/><sub>IconEyeBrightSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye-slash.svg" height="24"/><br/><sub>IconEyeSlash</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye-slash-solid.svg" height="24"/><br/><sub>IconEyeSlashSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye-tracking.svg" height="24"/><br/><sub>IconEyeTracking</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eye-tracking-solid.svg" height="24"/><br/><sub>IconEyeTrackingSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/eyedropper.svg" height="24"/><br/><sub>IconEyedropper</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/feed.svg" height="24"/><br/><sub>IconFeed</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/feed-solid.svg" height="24"/><br/><sub>IconFeedSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/feedback-solid.svg" height="24"/><br/><sub>IconFeedbackSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file.svg" height="24"/><br/><sub>IconFile</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-add.svg" height="24"/><br/><sub>IconFileAdd</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-add-solid.svg" height="24"/><br/><sub>IconFileAddSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-edit.svg" height="24"/><br/><sub>IconFileEdit</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-edit-solid.svg" height="24"/><br/><sub>IconFileEditSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-error.svg" height="24"/><br/><sub>IconFileError</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-error-solid.svg" height="24"/><br/><sub>IconFileErrorSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/file-solid.svg" height="24"/><br/><sub>IconFileSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/film.svg" height="24"/><br/><sub>IconFilm</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/film-solid.svg" height="24"/><br/><sub>IconFilmSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/filter.svg" height="24"/><br/><sub>IconFilter</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/filter-solid.svg" height="24"/><br/><sub>IconFilterSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/fire-solid.svg" height="24"/><br/><sub>IconFireSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/fit-width.svg" height="24"/><br/><sub>IconFitWidth</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/flag.svg" height="24"/><br/><sub>IconFlag</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/flag-solid.svg" height="24"/><br/><sub>IconFlagSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/folder.svg" height="24"/><br/><sub>IconFolder</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/folder-download.svg" height="24"/><br/><sub>IconFolderDownload</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/folder-download-solid.svg" height="24"/><br/><sub>IconFolderDownloadSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/folder-open.svg" height="24"/><br/><sub>IconFolderOpen</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/folder-open-solid.svg" height="24"/><br/><sub>IconFolderOpenSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/folder-solid.svg" height="24"/><br/><sub>IconFolderSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/font.svg" height="24"/><br/><sub>IconFont</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/font-size.svg" height="24"/><br/><sub>IconFontSize</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/four-dots.svg" height="24"/><br/><sub>IconFourDots</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/four-quarter-circles.svg" height="24"/><br/><sub>IconFourQuarterCircles</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/four-quarter-circles-solid.svg" height="24"/><br/><sub>IconFourQuarterCirclesSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/frowning-face.svg" height="24"/><br/><sub>IconFrowningFace</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/frowning-face-solid.svg" height="24"/><br/><sub>IconFrowningFaceSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/full-circle.svg" height="24"/><br/><sub>IconFullCircle</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/full-circle-solid.svg" height="24"/><br/><sub>IconFullCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/fullscreen.svg" height="24"/><br/><sub>IconFullscreen</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/fullscreen-exit.svg" height="24"/><br/><sub>IconFullscreenExit</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gallery.svg" height="24"/><br/><sub>IconGallery</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gallery-solid.svg" height="24"/><br/><sub>IconGallerySolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gamepad.svg" height="24"/><br/><sub>IconGamepad</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gamepad-solid.svg" height="24"/><br/><sub>IconGamepadSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gateway.svg" height="24"/><br/><sub>IconGateway</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gateway-solid.svg" height="24"/><br/><sub>IconGatewaySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gift.svg" height="24"/><br/><sub>IconGift</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/gift-solid.svg" height="24"/><br/><sub>IconGiftSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/girl.svg" height="24"/><br/><sub>IconGirl</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/girl-solid.svg" height="24"/><br/><sub>IconGirlSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/grade-circle.svg" height="24"/><br/><sub>IconGradeCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/grade-circle-solid.svg" height="24"/><br/><sub>IconGradeCircleSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hamburger.svg" height="24"/><br/><sub>IconHamburger</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hammer-solid.svg" height="24"/><br/><sub>IconHammerSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/headphones.svg" height="24"/><br/><sub>IconHeadphones</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/headphones-solid.svg" height="24"/><br/><sub>IconHeadphonesSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/heart.svg" height="24"/><br/><sub>IconHeart</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/heart-cancel.svg" height="24"/><br/><sub>IconHeartCancel</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/heart-cancel-solid.svg" height="24"/><br/><sub>IconHeartCancelSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/heart-solid.svg" height="24"/><br/><sub>IconHeartSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hierarchy.svg" height="24"/><br/><sub>IconHierarchy</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hierarchy-solid.svg" height="24"/><br/><sub>IconHierarchySolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/high-square.svg" height="24"/><br/><sub>IconHighSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/high-square-solid.svg" height="24"/><br/><sub>IconHighSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/home.svg" height="24"/><br/><sub>IconHome</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/home-solid.svg" height="24"/><br/><sub>IconHomeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hospital.svg" height="24"/><br/><sub>IconHospital</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hospital-solid.svg" height="24"/><br/><sub>IconHospitalSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hourglass.svg" height="24"/><br/><sub>IconHourglass</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/hourglass-solid.svg" height="24"/><br/><sub>IconHourglassSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/house.svg" height="24"/><br/><sub>IconHouse</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/house-solid.svg" height="24"/><br/><sub>IconHouseSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/id-card.svg" height="24"/><br/><sub>IconIdCard</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/id-card-back.svg" height="24"/><br/><sub>IconIdCardBack</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/id-card-back-solid.svg" height="24"/><br/><sub>IconIdCardBackSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/id-card-solid.svg" height="24"/><br/><sub>IconIdCardSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/image.svg" height="24"/><br/><sub>IconImage</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/image-add.svg" height="24"/><br/><sub>IconImageAdd</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/image-solid.svg" height="24"/><br/><sub>IconImageSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/import.svg" height="24"/><br/><sub>IconImport</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/indent.svg" height="24"/><br/><sub>IconIndent</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/info-circle.svg" height="24"/><br/><sub>IconInfoCircle</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/info-circle-solid.svg" height="24"/><br/><sub>IconInfoCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/infoflow.svg" height="24"/><br/><sub>IconInfoflow</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/intelligence.svg" height="24"/><br/><sub>IconIntelligence</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/intelligence-solid.svg" height="24"/><br/><sub>IconIntelligenceSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/invoice.svg" height="24"/><br/><sub>IconInvoice</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/invoice-solid.svg" height="24"/><br/><sub>IconInvoiceSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/italic.svg" height="24"/><br/><sub>IconItalic</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/landing-page-solid.svg" height="24"/><br/><sub>IconLandingPageSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/layer.svg" height="24"/><br/><sub>IconLayer</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/layer-solid.svg" height="24"/><br/><sub>IconLayerSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/layout.svg" height="24"/><br/><sub>IconLayout</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/layout-solid.svg" height="24"/><br/><sub>IconLayoutSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/letter-spacing.svg" height="24"/><br/><sub>IconLetterSpacing</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/line-chart.svg" height="24"/><br/><sub>IconLineChart</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/line-chart-alt.svg" height="24"/><br/><sub>IconLineChartAlt</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/line-chart-alt-solid.svg" height="24"/><br/><sub>IconLineChartAltSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/line-chart-solid.svg" height="24"/><br/><sub>IconLineChartSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/line-height.svg" height="24"/><br/><sub>IconLineHeight</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/link.svg" height="24"/><br/><sub>IconLink</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/link-alt.svg" height="24"/><br/><sub>IconLinkAlt</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/link-alt-solid.svg" height="24"/><br/><sub>IconLinkAltSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/list-checked.svg" height="24"/><br/><sub>IconListChecked</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/list-ordered.svg" height="24"/><br/><sub>IconListOrdered</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/list-unordered.svg" height="24"/><br/><sub>IconListUnordered</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/loading.svg" height="24"/><br/><sub>IconLoading</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/location.svg" height="24"/><br/><sub>IconLocation</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/location-copy.svg" height="24"/><br/><sub>IconLocationCopy</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/location-copy-solid.svg" height="24"/><br/><sub>IconLocationCopySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/location-pin.svg" height="24"/><br/><sub>IconLocationPin</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/location-pin-solid.svg" height="24"/><br/><sub>IconLocationPinSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/location-solid.svg" height="24"/><br/><sub>IconLocationSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/lock.svg" height="24"/><br/><sub>IconLock</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/lock-solid.svg" height="24"/><br/><sub>IconLockSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/long-video.svg" height="24"/><br/><sub>IconLongVideo</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/long-video-solid.svg" height="24"/><br/><sub>IconLongVideoSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/low-square.svg" height="24"/><br/><sub>IconLowSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/low-square-solid.svg" height="24"/><br/><sub>IconLowSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/magic-wand.svg" height="24"/><br/><sub>IconMagicWand</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/magic-wand-solid.svg" height="24"/><br/><sub>IconMagicWandSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/market.svg" height="24"/><br/><sub>IconMarket</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/market-solid.svg" height="24"/><br/><sub>IconMarketSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/media-add.svg" height="24"/><br/><sub>IconMediaAdd</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/medium-square.svg" height="24"/><br/><sub>IconMediumSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/medium-square-solid.svg" height="24"/><br/><sub>IconMediumSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/migrate.svg" height="24"/><br/><sub>IconMigrate</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/migrate-solid.svg" height="24"/><br/><sub>IconMigrateSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mini-app-baidu.svg" height="24"/><br/><sub>IconMiniAppBaidu</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mini-app-baidu-solid.svg" height="24"/><br/><sub>IconMiniAppBaiduSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mini-app-wechat.svg" height="24"/><br/><sub>IconMiniAppWechat</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/minimize.svg" height="24"/><br/><sub>IconMinimize</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/minus.svg" height="24"/><br/><sub>IconMinus</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/minus-circle.svg" height="24"/><br/><sub>IconMinusCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/minus-circle-solid.svg" height="24"/><br/><sub>IconMinusCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mobile-app.svg" height="24"/><br/><sub>IconMobileApp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mobile-app-solid.svg" height="24"/><br/><sub>IconMobileAppSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/motion-graphics.svg" height="24"/><br/><sub>IconMotionGraphics</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/move.svg" height="24"/><br/><sub>IconMove</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/music.svg" height="24"/><br/><sub>IconMusic</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/music-solid.svg" height="24"/><br/><sub>IconMusicSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mute.svg" height="24"/><br/><sub>IconMute</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/mute-solid.svg" height="24"/><br/><sub>IconMuteSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/neutral-face.svg" height="24"/><br/><sub>IconNeutralFace</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/neutral-face-solid.svg" height="24"/><br/><sub>IconNeutralFaceSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/one-to-one.svg" height="24"/><br/><sub>IconOneToOne</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/one-to-one-solid.svg" height="24"/><br/><sub>IconOneToOneSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/order.svg" height="24"/><br/><sub>IconOrder</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/order-solid.svg" height="24"/><br/><sub>IconOrderSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/outdent.svg" height="24"/><br/><sub>IconOutdent</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/outstanding.svg" height="24"/><br/><sub>IconOutstanding</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/outstanding-solid.svg" height="24"/><br/><sub>IconOutstandingSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paint-bucket.svg" height="24"/><br/><sub>IconPaintBucket</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paint-bucket-solid.svg" height="24"/><br/><sub>IconPaintBucketSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paper-clip.svg" height="24"/><br/><sub>IconPaperClip</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paper-plane.svg" height="24"/><br/><sub>IconPaperPlane</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paper-plane-solid.svg" height="24"/><br/><sub>IconPaperPlaneSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paste.svg" height="24"/><br/><sub>IconPaste</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/paste-solid.svg" height="24"/><br/><sub>IconPasteSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/path.svg" height="24"/><br/><sub>IconPath</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/path-solid.svg" height="24"/><br/><sub>IconPathSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pause.svg" height="24"/><br/><sub>IconPause</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pause-circle.svg" height="24"/><br/><sub>IconPauseCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pause-circle-solid.svg" height="24"/><br/><sub>IconPauseCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pencil.svg" height="24"/><br/><sub>IconPencil</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pencil-solid.svg" height="24"/><br/><sub>IconPencilSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/phone.svg" height="24"/><br/><sub>IconPhone</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/phone-call.svg" height="24"/><br/><sub>IconPhoneCall</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/phone-call-solid.svg" height="24"/><br/><sub>IconPhoneCallSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/phone-eye.svg" height="24"/><br/><sub>IconPhoneEye</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/phone-eye-solid.svg" height="24"/><br/><sub>IconPhoneEyeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/phone-solid.svg" height="24"/><br/><sub>IconPhoneSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pie-chart.svg" height="24"/><br/><sub>IconPieChart</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pie-chart-solid.svg" height="24"/><br/><sub>IconPieChartSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/play.svg" height="24"/><br/><sub>IconPlay</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/play-circle.svg" height="24"/><br/><sub>IconPlayCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/play-circle-solid.svg" height="24"/><br/><sub>IconPlayCircleSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/plus.svg" height="24"/><br/><sub>IconPlus</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/plus-circle.svg" height="24"/><br/><sub>IconPlusCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/plus-circle-solid.svg" height="24"/><br/><sub>IconPlusCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/plus-square.svg" height="24"/><br/><sub>IconPlusSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/plus-square-solid.svg" height="24"/><br/><sub>IconPlusSquareSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/power-off.svg" height="24"/><br/><sub>IconPowerOff</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/puzzle-piece.svg" height="24"/><br/><sub>IconPuzzlePiece</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/puzzle-piece-solid.svg" height="24"/><br/><sub>IconPuzzlePieceSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pv-shield.svg" height="24"/><br/><sub>IconPvShield</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/pv-shield-solid.svg" height="24"/><br/><sub>IconPvShieldSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/qrcode.svg" height="24"/><br/><sub>IconQrcode</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/quality-circle.svg" height="24"/><br/><sub>IconQualityCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/quality-circle-solid.svg" height="24"/><br/><sub>IconQualityCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/question-circle.svg" height="24"/><br/><sub>IconQuestionCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/question-circle-solid.svg" height="24"/><br/><sub>IconQuestionCircleSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/question-comment.svg" height="24"/><br/><sub>IconQuestionComment</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/question-comment-solid.svg" height="24"/><br/><sub>IconQuestionCommentSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/recommend-square.svg" height="24"/><br/><sub>IconRecommendSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/recommend-square-solid.svg" height="24"/><br/><sub>IconRecommendSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/recommendation.svg" height="24"/><br/><sub>IconRecommendation</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/redo.svg" height="24"/><br/><sub>IconRedo</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/redo-solid.svg" height="24"/><br/><sub>IconRedoSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report.svg" height="24"/><br/><sub>IconReport</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-bookmark.svg" height="24"/><br/><sub>IconReportBookmark</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-bookmark-solid.svg" height="24"/><br/><sub>IconReportBookmarkSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-check.svg" height="24"/><br/><sub>IconReportCheck</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-check-solid.svg" height="24"/><br/><sub>IconReportCheckSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-search.svg" height="24"/><br/><sub>IconReportSearch</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-search-solid.svg" height="24"/><br/><sub>IconReportSearchSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-settings.svg" height="24"/><br/><sub>IconReportSettings</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-settings-solid.svg" height="24"/><br/><sub>IconReportSettingsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-solid.svg" height="24"/><br/><sub>IconReportSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-stamp.svg" height="24"/><br/><sub>IconReportStamp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-stamp-solid.svg" height="24"/><br/><sub>IconReportStampSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-star.svg" height="24"/><br/><sub>IconReportStar</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-star-solid.svg" height="24"/><br/><sub>IconReportStarSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-trend-settings.svg" height="24"/><br/><sub>IconReportTrendSettings</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-trend-settings-solid.svg" height="24"/><br/><sub>IconReportTrendSettingsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-user.svg" height="24"/><br/><sub>IconReportUser</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/report-user-solid.svg" height="24"/><br/><sub>IconReportUserSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/road.svg" height="24"/><br/><sub>IconRoad</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/rocket-solid.svg" height="24"/><br/><sub>IconRocketSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/rotate-anticlockwise.svg" height="24"/><br/><sub>IconRotateAnticlockwise</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/rotate-anticlockwise-solid.svg" height="24"/><br/><sub>IconRotateAnticlockwiseSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/rotate-clockwise.svg" height="24"/><br/><sub>IconRotateClockwise</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/rotate-clockwise-solid.svg" height="24"/><br/><sub>IconRotateClockwiseSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/save.svg" height="24"/><br/><sub>IconSave</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/save-solid.svg" height="24"/><br/><sub>IconSaveSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/scan.svg" height="24"/><br/><sub>IconScan</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/search.svg" height="24"/><br/><sub>IconSearch</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/search-desktop.svg" height="24"/><br/><sub>IconSearchDesktop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/search-desktop-solid.svg" height="24"/><br/><sub>IconSearchDesktopSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/search-history.svg" height="24"/><br/><sub>IconSearchHistory</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/search-history-solid.svg" height="24"/><br/><sub>IconSearchHistorySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/search-solid.svg" height="24"/><br/><sub>IconSearchSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/settings.svg" height="24"/><br/><sub>IconSettings</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/settings-solid.svg" height="24"/><br/><sub>IconSettingsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/share.svg" height="24"/><br/><sub>IconShare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/share-alt.svg" height="24"/><br/><sub>IconShareAlt</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/share-alt-solid.svg" height="24"/><br/><sub>IconShareAltSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-check.svg" height="24"/><br/><sub>IconShieldCheck</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-check-solid.svg" height="24"/><br/><sub>IconShieldCheckSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-cny-solid.svg" height="24"/><br/><sub>IconShieldCnySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-ellipsis-solid.svg" height="24"/><br/><sub>IconShieldEllipsisSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-times-solid.svg" height="24"/><br/><sub>IconShieldTimesSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-user.svg" height="24"/><br/><sub>IconShieldUser</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-user-solid.svg" height="24"/><br/><sub>IconShieldUserSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shield-wave-solid.svg" height="24"/><br/><sub>IconShieldWaveSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shopping-bag.svg" height="24"/><br/><sub>IconShoppingBag</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shopping-bag-solid.svg" height="24"/><br/><sub>IconShoppingBagSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shopping-cart.svg" height="24"/><br/><sub>IconShoppingCart</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shopping-cart-solid.svg" height="24"/><br/><sub>IconShoppingCartSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/short-video.svg" height="24"/><br/><sub>IconShortVideo</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/short-video-solid.svg" height="24"/><br/><sub>IconShortVideoSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/shrink.svg" height="24"/><br/><sub>IconShrink</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sign-out.svg" height="24"/><br/><sub>IconSignOut</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sliders-square.svg" height="24"/><br/><sub>IconSlidersSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sliders-square-solid.svg" height="24"/><br/><sub>IconSlidersSquareSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/smiley.svg" height="24"/><br/><sub>IconSmiley</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/smiley-solid.svg" height="24"/><br/><sub>IconSmileySolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/smiley-star.svg" height="24"/><br/><sub>IconSmileyStar</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/smiley-star-solid.svg" height="24"/><br/><sub>IconSmileyStarSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sort.svg" height="24"/><br/><sub>IconSort</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sort-alt.svg" height="24"/><br/><sub>IconSortAlt</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sort-asc.svg" height="24"/><br/><sub>IconSortAsc</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sort-desc.svg" height="24"/><br/><sub>IconSortDesc</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sound-wave.svg" height="24"/><br/><sub>IconSoundWave</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/square-rotation.svg" height="24"/><br/><sub>IconSquareRotation</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/square-rotation-solid.svg" height="24"/><br/><sub>IconSquareRotationSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/stamp.svg" height="24"/><br/><sub>IconStamp</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/stamp-solid.svg" height="24"/><br/><sub>IconStampSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/star.svg" height="24"/><br/><sub>IconStar</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/star-dash.svg" height="24"/><br/><sub>IconStarDash</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/star-dash-soild.svg" height="24"/><br/><sub>IconStarDashSoild</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/star-half.svg" height="24"/><br/><sub>IconStarHalf</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/star-solid.svg" height="24"/><br/><sub>IconStarSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/stop.svg" height="24"/><br/><sub>IconStop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/stop-solid.svg" height="24"/><br/><sub>IconStopSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/strikethrough.svg" height="24"/><br/><sub>IconStrikethrough</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/sync.svg" height="24"/><br/><sub>IconSync</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/tag.svg" height="24"/><br/><sub>IconTag</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/tag-solid.svg" height="24"/><br/><sub>IconTagSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/team.svg" height="24"/><br/><sub>IconTeam</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/team-solid.svg" height="24"/><br/><sub>IconTeamSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/telephone.svg" height="24"/><br/><sub>IconTelephone</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/telephone-solid.svg" height="24"/><br/><sub>IconTelephoneSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/template.svg" height="24"/><br/><sub>IconTemplate</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/template-solid.svg" height="24"/><br/><sub>IconTemplateSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/text-square.svg" height="24"/><br/><sub>IconTextSquare</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/text-square-solid.svg" height="24"/><br/><sub>IconTextSquareSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/thumb-down.svg" height="24"/><br/><sub>IconThumbDown</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/thumb-down-solid.svg" height="24"/><br/><sub>IconThumbDownSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/thumb-up.svg" height="24"/><br/><sub>IconThumbUp</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/thumb-up-solid.svg" height="24"/><br/><sub>IconThumbUpSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/times.svg" height="24"/><br/><sub>IconTimes</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/times-circle.svg" height="24"/><br/><sub>IconTimesCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/times-circle-solid.svg" height="24"/><br/><sub>IconTimesCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/toolbox.svg" height="24"/><br/><sub>IconToolbox</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/toolbox-solid.svg" height="24"/><br/><sub>IconToolboxSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trash.svg" height="24"/><br/><sub>IconTrash</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trash-solid.svg" height="24"/><br/><sub>IconTrashSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/treasure-chest.svg" height="24"/><br/><sub>IconTreasureChest</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/treasure-chest-solid.svg" height="24"/><br/><sub>IconTreasureChestSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-desktop.svg" height="24"/><br/><sub>IconTrendDesktop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-desktop-solid.svg" height="24"/><br/><sub>IconTrendDesktopSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-monitor.svg" height="24"/><br/><sub>IconTrendMonitor</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-monitor-solid.svg" height="24"/><br/><sub>IconTrendMonitorSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-pages.svg" height="24"/><br/><sub>IconTrendPages</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-pages-solid.svg" height="24"/><br/><sub>IconTrendPagesSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-report.svg" height="24"/><br/><sub>IconTrendReport</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trend-report-solid.svg" height="24"/><br/><sub>IconTrendReportSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trophy.svg" height="24"/><br/><sub>IconTrophy</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/trophy-solid.svg" height="24"/><br/><sub>IconTrophySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/truck.svg" height="24"/><br/><sub>IconTruck</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/truck-solid.svg" height="24"/><br/><sub>IconTruckSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/tv.svg" height="24"/><br/><sub>IconTv</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/tv-solid.svg" height="24"/><br/><sub>IconTvSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/two-hearts.svg" height="24"/><br/><sub>IconTwoHearts</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/two-hearts-solid.svg" height="24"/><br/><sub>IconTwoHeartsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/underline.svg" height="24"/><br/><sub>IconUnderline</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/undo.svg" height="24"/><br/><sub>IconUndo</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/undo-solid.svg" height="24"/><br/><sub>IconUndoSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/unlink.svg" height="24"/><br/><sub>IconUnlink</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/unlock.svg" height="24"/><br/><sub>IconUnlock</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/unlock-solid.svg" height="24"/><br/><sub>IconUnlockSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/update-wave.svg" height="24"/><br/><sub>IconUpdateWave</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/upgrade.svg" height="24"/><br/><sub>IconUpgrade</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/upgrade-solid.svg" height="24"/><br/><sub>IconUpgradeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/upload.svg" height="24"/><br/><sub>IconUpload</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/upload-desktop.svg" height="24"/><br/><sub>IconUploadDesktop</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/upload-desktop-solid.svg" height="24"/><br/><sub>IconUploadDesktopSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user.svg" height="24"/><br/><sub>IconUser</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-bookmark.svg" height="24"/><br/><sub>IconUserBookmark</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-bookmark-solid.svg" height="24"/><br/><sub>IconUserBookmarkSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-card.svg" height="24"/><br/><sub>IconUserCard</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-card-solid.svg" height="24"/><br/><sub>IconUserCardSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-circle.svg" height="24"/><br/><sub>IconUserCircle</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-circle-solid.svg" height="24"/><br/><sub>IconUserCircleSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-combined.svg" height="24"/><br/><sub>IconUserCombined</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-combined-solid.svg" height="24"/><br/><sub>IconUserCombinedSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-filter.svg" height="24"/><br/><sub>IconUserFilter</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-filter-solid.svg" height="24"/><br/><sub>IconUserFilterSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-intersection.svg" height="24"/><br/><sub>IconUserIntersection</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-intersection-solid.svg" height="24"/><br/><sub>IconUserIntersectionSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-label.svg" height="24"/><br/><sub>IconUserLabel</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-label-solid.svg" height="24"/><br/><sub>IconUserLabelSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-mobile.svg" height="24"/><br/><sub>IconUserMobile</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-mobile-solid.svg" height="24"/><br/><sub>IconUserMobileSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-search.svg" height="24"/><br/><sub>IconUserSearch</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-search-solid.svg" height="24"/><br/><sub>IconUserSearchSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-settings.svg" height="24"/><br/><sub>IconUserSettings</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-settings-solid.svg" height="24"/><br/><sub>IconUserSettingsSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-solid.svg" height="24"/><br/><sub>IconUserSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-sync.svg" height="24"/><br/><sub>IconUserSync</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-sync-solid.svg" height="24"/><br/><sub>IconUserSyncSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/user-tieba.svg" height="24"/><br/><sub>IconUserTieba</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video.svg" height="24"/><br/><sub>IconVideo</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-add.svg" height="24"/><br/><sub>IconVideoAdd</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-crop.svg" height="24"/><br/><sub>IconVideoCrop</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-crop-solid.svg" height="24"/><br/><sub>IconVideoCropSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-film.svg" height="24"/><br/><sub>IconVideoFilm</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-film-solid.svg" height="24"/><br/><sub>IconVideoFilmSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-history.svg" height="24"/><br/><sub>IconVideoHistory</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-history-solid.svg" height="24"/><br/><sub>IconVideoHistorySolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/video-solid.svg" height="24"/><br/><sub>IconVideoSolid</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/volume.svg" height="24"/><br/><sub>IconVolume</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/volume-solid.svg" height="24"/><br/><sub>IconVolumeSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/whirlpool.svg" height="24"/><br/><sub>IconWhirlpool</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/whirlpool-solid.svg" height="24"/><br/><sub>IconWhirlpoolSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/yingxiaotong.svg" height="24"/><br/><sub>IconYingxiaotong</sub></td></tr><tr><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/yingxiaotong-solid.svg" height="24"/><br/><sub>IconYingxiaotongSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/zoom-in.svg" height="24"/><br/><sub>IconZoomIn</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/zoom-in-solid.svg" height="24"/><br/><sub>IconZoomInSolid</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/zoom-out.svg" height="24"/><br/><sub>IconZoomOut</sub></td><td align="center"><img src="https://raw.githubusercontent.com/ecomfe/dls-icons/master/svg/zoom-out-solid.svg" height="24"/><br/><sub>IconZoomOutSolid</sub></td></tr></tbody></table><!-- icons:end -->
